@@ -3,12 +3,14 @@
 from mcipc.rcon.client import Client
 from mcipc.rcon.console import rconcmd
 from mcipc.rcon.exceptions import InvalidPacketStructure
+from mcipc.rcon.exceptions import RequestIdMismatch
 from mcipc.rcon.exceptions import StructureNotFound
 from mcipc.rcon.exceptions import WrongPassword
 
 
 __all__ = [
     'InvalidPacketStructure',
+    'RequestIdMismatch',
     'StructureNotFound',
     'WrongPassword',
     'rconcmd',
