@@ -3,10 +3,17 @@
 from mcipc.server.datastructures import Handshake, SLPResponse
 from mcipc.server.datatypes import VarInt
 from mcipc.server.enumerations import State
-from mcipc.server.server import get_response, StubServer
+from mcipc.server.server import MAX_PLAYERS
+from mcipc.server.server import PROTOCOL
+from mcipc.server.server import VERSION
+from mcipc.server.server import get_response
+from mcipc.server.server import StubServer
 
 
 __all__ = [
+    'MAX_PLAYERS',
+    'PROTOCOL',
+    'VERSION',
     'get_response',
     'Handshake',
     'SLPResponse',
